"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Asset = void 0;
class Asset {
  constructor(props) {
    this.props = props;
  }
  clone() {
    return this.withProps(structuredClone(this.props));
  }
  withProps(props) {
    const newAsset = new Asset({
      ...this.props,
      ...props
    });
    newAsset.contentsReader = this.contentsReader;
    newAsset.outputStrategy = this.outputStrategy;
    return newAsset;
  }
  getId() {
    return this.props.id;
  }
  getTenant() {
    return this.props.tenant;
  }
  getLocale() {
    return this.props.locale;
  }
  getKey() {
    return this.props.key;
  }
  getSize() {
    return this.props.size;
  }
  getContentType() {
    return this.props.contentType;
  }
  getExtension() {
    return this.getKey().split(".").pop() ?? "";
  }
  getContents() {
    if (!this.contentsReader) {
      throw Error(`Asset contents reader was not configured!`);
    }
    return this.contentsReader.read(this);
  }
  setContentsReader(reader) {
    this.contentsReader = reader;
  }
  output() {
    if (!this.outputStrategy) {
      throw Error(`Asset output strategy was not configured!`);
    }
    return this.outputStrategy.output(this);
  }
  setOutputStrategy(setter) {
    if (typeof setter === "function") {
      this.outputStrategy = setter(this.outputStrategy);
    } else {
      this.outputStrategy = setter;
    }
  }
}
exports.Asset = Asset;

//# sourceMappingURL=Asset.js.map